/*
 * This file Copyright (C) 2008-2010 Mnemosyne LLC
 *
 * This file is licensed by the GPL version 2.  Works owned by the
 * Transmission project are granted a special exemption to clause 2(b)
 * so that the bulk of its code can remain under the MIT license.
 * This exemption does not extend to derived works not owned by
 * the Transmission project.
 *
 * $Id: msgwin.h 11337 2010-10-18 22:18:15Z charles $
 */

#ifndef TG_MSGWIN_H
#define TG_MSGWIN_H

GtkWidget * msgwin_new( TrCore * core, GtkWindow * parent );

#endif
